@@ -11,7 +11,7 @@
 #' dL <- data.frame(x = 1, y = 2, z = 3)
 #' rquery_pipeline <- local_td(dL) %.>%
 #'   select_columns(., "y")
-#' ex_data_table(rquery_pipeline)[]
+#' ex_data_table(rquery_pipeline)
 #'
 #' @export
 ex_data_table.relop_select_columns <- function(optree,
@@ -30,6 +30,6 @@ ex_data_table.relop_select_columns <- function(optree,
                      source_usage = source_usage,
                      source_limit = source_limit,
                      env = env)
-  x[, cols, with=FALSE]
+  x[, cols, with=FALSE] # data.table semantics (drop=FALSE implicit)
 }
 
